%
%	Right hand side of an IVP with shape
%		y' = f(t, y); 	y(t0) = y0
%
% 	Arguments:
% 		t    (scalar)    Time.
% 		y    (vector)    Value.
%
% 	Returns:
% 		f    (vector)    Evaluation of f at (t,y).
%
function [f] = rhs(t, y)
	f = y;
